==> open-cluster-management-agent-model-5.12.2-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KlusterletAddonConfigSpecBuilder extends io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecFluentImpl<io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpec,io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecBuilder>{
  public KlusterletAddonConfigSpecBuilder() {
    this(false);
  }
  public KlusterletAddonConfigSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public KlusterletAddonConfigSpecBuilder(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecFluent<?> fluent,io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpec instance) {
    this(fluent, instance, false);
  }
  public KlusterletAddonConfigSpecBuilder(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecFluent<?> fluent,io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplicationManager(instance.getApplicationManager()); 
    fluent.withCertPolicyController(instance.getCertPolicyController()); 
    fluent.withClusterLabels(instance.getClusterLabels()); 
    fluent.withClusterName(instance.getClusterName()); 
    fluent.withClusterNamespace(instance.getClusterNamespace()); 
    fluent.withIamPolicyController(instance.getIamPolicyController()); 
    fluent.withPolicyController(instance.getPolicyController()); 
    fluent.withProxyConfig(instance.getProxyConfig()); 
    fluent.withSearchCollector(instance.getSearchCollector()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public KlusterletAddonConfigSpecBuilder(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpec instance) {
    this(instance,false);
  }
  public KlusterletAddonConfigSpecBuilder(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplicationManager(instance.getApplicationManager()); 
    this.withCertPolicyController(instance.getCertPolicyController()); 
    this.withClusterLabels(instance.getClusterLabels()); 
    this.withClusterName(instance.getClusterName()); 
    this.withClusterNamespace(instance.getClusterNamespace()); 
    this.withIamPolicyController(instance.getIamPolicyController()); 
    this.withPolicyController(instance.getPolicyController()); 
    this.withProxyConfig(instance.getProxyConfig()); 
    this.withSearchCollector(instance.getSearchCollector()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfigSpec build() {
    KlusterletAddonConfigSpec buildable = new KlusterletAddonConfigSpec(fluent.getApplicationManager(),fluent.getCertPolicyController(),fluent.getClusterLabels(),fluent.getClusterName(),fluent.getClusterNamespace(),fluent.getIamPolicyController(),fluent.getPolicyController(),fluent.getProxyConfig(),fluent.getSearchCollector(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KlusterletAddonConfigSpecBuilder that = (KlusterletAddonConfigSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-agent-model-6.4.0-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KlusterletAddonConfigSpecBuilder extends KlusterletAddonConfigSpecFluentImpl<KlusterletAddonConfigSpecBuilder> implements VisitableBuilder<KlusterletAddonConfigSpec,KlusterletAddonConfigSpecBuilder>{
  public KlusterletAddonConfigSpecBuilder() {
    this(false);
  }
  public KlusterletAddonConfigSpecBuilder(Boolean validationEnabled) {
    this(new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,KlusterletAddonConfigSpec instance) {
    this(fluent, instance, false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,KlusterletAddonConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplicationManager(instance.getApplicationManager()); 
    fluent.withCertPolicyController(instance.getCertPolicyController()); 
    fluent.withClusterLabels(instance.getClusterLabels()); 
    fluent.withClusterName(instance.getClusterName()); 
    fluent.withClusterNamespace(instance.getClusterNamespace()); 
    fluent.withIamPolicyController(instance.getIamPolicyController()); 
    fluent.withPolicyController(instance.getPolicyController()); 
    fluent.withProxyConfig(instance.getProxyConfig()); 
    fluent.withSearchCollector(instance.getSearchCollector()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpec instance) {
    this(instance,false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplicationManager(instance.getApplicationManager()); 
    this.withCertPolicyController(instance.getCertPolicyController()); 
    this.withClusterLabels(instance.getClusterLabels()); 
    this.withClusterName(instance.getClusterName()); 
    this.withClusterNamespace(instance.getClusterNamespace()); 
    this.withIamPolicyController(instance.getIamPolicyController()); 
    this.withPolicyController(instance.getPolicyController()); 
    this.withProxyConfig(instance.getProxyConfig()); 
    this.withSearchCollector(instance.getSearchCollector()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  KlusterletAddonConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public KlusterletAddonConfigSpec build() {
    KlusterletAddonConfigSpec buildable = new KlusterletAddonConfigSpec(fluent.getApplicationManager(),fluent.getCertPolicyController(),fluent.getClusterLabels(),fluent.getClusterName(),fluent.getClusterNamespace(),fluent.getIamPolicyController(),fluent.getPolicyController(),fluent.getProxyConfig(),fluent.getSearchCollector(),fluent.getVersion());
    return buildable;
  }
  
}
